Struct presenterm::CommandSource
source · pub struct CommandSource { /* private fields */ }Expand description
The source of commands.
This expects user commands as well as watches over the presentation file to reload if it that happens.
Implementations